@@ -119,7 +119,7 @@ export =  qtycon <**> (tcExportWith <$> parensSp spec `opt` tcExport)
           updateEndPos $ setSrcInfoPoints (sp1 : (ss ++ [sp2])) $
           spc (fromSrcSpan (getSrcSpan qtc)) qtc
         exportTypeWith' c spi qtc = ExportTypeWith spi qtc c
-        exportModule' sp = updateEndPos . ExportModule (SpanInfo sp [])
+        exportModule' sp = updateEndPos . ExportModule (SpanInfo sp [sp])
 
 moduleDecls :: Parser a Token ([ImportDecl], [Decl ()])
 moduleDecls = impDecl <$> importDecl
@@ -331,8 +331,7 @@ typeDeclLhs :: (Span -> Ident -> [Ident] -> a) -> Category
 typeDeclLhs f kw = f <$> tokenSpan kw <*> tycon <*> many anonOrTyvar
 
 constrDecl :: Parser a Token ConstrDecl
-constrDecl = spanPosition <**> (existVars
-                          <**> optContext (\cx sp f -> f sp cx) constr)
+constrDecl = spanPosition <**> constr
   where
   constr =  conId     <**> identDecl
         <|> tokenSpan LeftParen <**> parenDecl
@@ -348,16 +347,16 @@ constrDecl = spanPosition <**> (existVars
   conType f tys c = f $ foldl mkApply (mkConstructorType $ qualify c) tys
   mkApply t1 t2 = updateEndPos $ ApplyType (fromSrcSpan (getSrcSpan t1)) t1 t2
   mkConstructorType qid = ConstructorType (fromSrcSpan (getSrcSpan qid)) qid
-  conDecl tys c ss1 cx (ss2, tvs) sp = updateEndPos $
-    ConstrDecl (SpanInfo sp (ss2 ++ ss1)) tvs cx c tys
-  conOpDecl op ty2 ty1 ss1 cx (ss2, tvs) sp = updateEndPos $
-    ConOpDecl (SpanInfo sp (ss2 ++ ss1)) tvs cx ty1 op ty2
-  conOpDeclParen op ty2 sp1 ty1 sp2 ss1 cx (ss2, tvs) sp5 = updateEndPos $
-    ConOpDecl (SpanInfo sp5 (ss2 ++ ss1 ++ [sp2, sp1])) tvs cx ty1 op ty2
-  conOpDeclPrefix op sp1 ty1 ty2 sp2 ss1 cx (ss2, tvs) sp3 = updateEndPos $
-    ConOpDecl (SpanInfo sp3 (ss2 ++ ss1 ++ [sp2,sp1])) tvs cx ty1 op ty2
-  recDecl ((fs, ss), sp1, sp2) c ss1 cx (ss2, tvs) sp3 = updateEndPos $
-    RecordDecl (SpanInfo sp3 (ss2 ++ ss1 ++ (sp1: (ss ++ [sp2])))) tvs cx c fs
+  conDecl tys c sp = updateEndPos $
+    ConstrDecl (SpanInfo sp []) c tys
+  conOpDecl op ty2 ty1 sp = updateEndPos $
+    ConOpDecl (SpanInfo sp []) ty1 op ty2
+  conOpDeclParen op ty2 sp1 ty1 sp2 sp5 = updateEndPos $
+    ConOpDecl (SpanInfo sp5 [sp2, sp1]) ty1 op ty2
+  conOpDeclPrefix op sp1 ty1 ty2 sp2 sp3 = updateEndPos $
+    ConOpDecl (SpanInfo sp3 [sp2, sp1]) ty1 op ty2
+  recDecl ((fs, ss), sp1, sp2) c sp3 = updateEndPos $
+    RecordDecl (SpanInfo sp3 (sp1 : ss ++ [sp2])) c fs
 
 fieldDecl :: Parser a Token FieldDecl
 fieldDecl = mkFieldDecl <$> spanPosition <*> labels
@@ -386,13 +385,6 @@ deriv = (addSpan <$> tokenSpan KW_deriving <*> classes) `opt` ([], [])
                       <*> (qtycls `sepBySp` comma)
                       <*> tokenSpan RightParen)
 
--- Parsing of existential variables
-existVars :: Parser a Token ([Span], [Ident])
-existVars = mk <$> tokenSpan Id_forall <*> many1 tyvar <*>
-                   tokenSpan SymDot
-              `opt` ([],[])
-  where mk sp1 a sp2 = ([sp1,sp2], a)
-
 functionDecl :: Parser a Token (Decl ())
 functionDecl = spanPosition <**> decl
   where decl = fun `sepBy1Sp` comma <**> funListDecl <|?> funRule
@@ -1316,9 +1308,6 @@ parensSp p = (\sp1 b sp2 -> (b, sp1, sp2))
                <*> p
                <*> tokenSpan RightParen
 
-backquotes :: Parser a Token b -> Parser a Token b
-backquotes p = between backquote p expectBackquote
-
 backquotesSp :: Parser a Token b -> Parser a Token (b, Span, Span)
 backquotesSp p = (\sp1 b sp2 -> (b, sp1, sp2))
                    <$> tokenSpan Backquote
