@@ -155,18 +155,12 @@ ppTypeDeclLhs :: String -> Ident -> [Ident] -> Doc
 ppTypeDeclLhs kw tc tvs = text kw <+> ppIdent tc <+> hsep (map ppIdent tvs)
 
 ppConstr :: ConstrDecl -> Doc
-ppConstr (ConstrDecl     _ tvs cx c tys) =
-  sep [ ppQuantifiedVars tvs <+> ppContext cx
-      , ppIdent c <+> fsep (map (ppTypeExpr 2) tys)
-      ]
-ppConstr (ConOpDecl _ tvs cx ty1 op ty2) =
-  sep [ ppQuantifiedVars tvs <+> ppContext cx
-      , ppTypeExpr 1 ty1, ppInfixOp op <+> ppTypeExpr 1 ty2
-      ]
-ppConstr (RecordDecl _ tvs cx c fs) =
-  sep [ ppQuantifiedVars tvs <+> ppContext cx
-      , ppIdent c <+> record (list (map ppFieldDecl fs))
-      ]
+ppConstr (ConstrDecl     _ c tys) =
+  sep [ ppIdent c <+> fsep (map (ppTypeExpr 2) tys) ]
+ppConstr (ConOpDecl _ ty1 op ty2) =
+  sep [ ppTypeExpr 1 ty1, ppInfixOp op <+> ppTypeExpr 1 ty2 ]
+ppConstr (RecordDecl _ c fs)      =
+  sep [ ppIdent c <+> record (list (map ppFieldDecl fs)) ]
 
 ppFieldDecl :: FieldDecl -> Doc
 ppFieldDecl (FieldDecl _ ls ty) = list (map ppIdent ls)
