@@ -235,28 +235,22 @@ showsInstanceType :: InstanceType -> ShowS
 showsInstanceType = showsTypeExpr
 
 showsConsDecl :: ConstrDecl -> ShowS
-showsConsDecl (ConstrDecl spi idents context ident types)
+showsConsDecl (ConstrDecl spi ident types)
   = showsString "(ConstrDecl "
   . showsSpanInfo spi . space
-  . showsList showsIdent idents . space
-  . showsContext context . space
   . showsIdent ident . space
   . showsList showsTypeExpr types
   . showsString ")"
-showsConsDecl (ConOpDecl spi idents context ty1 ident ty2)
+showsConsDecl (ConOpDecl spi ty1 ident ty2)
   = showsString "(ConOpDecl "
   . showsSpanInfo spi . space
-  . showsList showsIdent idents . space
-  . showsContext context . space
   . showsTypeExpr ty1 . space
   . showsIdent ident . space
   . showsTypeExpr ty2
   . showsString ")"
-showsConsDecl (RecordDecl spi idents context ident fs)
+showsConsDecl (RecordDecl spi ident fs)
   = showsString "(RecordDecl "
   . showsSpanInfo spi . space
-  . showsList showsIdent idents . space
-  . showsContext context . space
   . showsIdent ident . space
   . showsList showsFieldDecl fs
   . showsString ")"
