@@ -182,9 +182,9 @@ data Infix
 
 -- |Constructor declaration for algebraic data types
 data ConstrDecl
-  = ConstrDecl SpanInfo [Ident] Context Ident [TypeExpr]
-  | ConOpDecl  SpanInfo [Ident] Context TypeExpr Ident TypeExpr
-  | RecordDecl SpanInfo [Ident] Context Ident [FieldDecl]
+  = ConstrDecl SpanInfo Ident [TypeExpr]
+  | ConOpDecl  SpanInfo TypeExpr Ident TypeExpr
+  | RecordDecl SpanInfo Ident [FieldDecl]
     deriving (Eq, Read, Show)
 
 -- |Constructor declaration for renaming types (newtypes)
@@ -644,23 +644,23 @@ instance HasSpanInfo Import where
   updateEndPos i@(ImportTypeAll _ _) = i
 
 instance HasSpanInfo ConstrDecl where
-  getSpanInfo (ConstrDecl sp _ _ _ _)   = sp
-  getSpanInfo (ConOpDecl  sp _ _ _ _ _) = sp
-  getSpanInfo (RecordDecl sp _ _ _ _)   = sp
+  getSpanInfo (ConstrDecl sp _ _)   = sp
+  getSpanInfo (ConOpDecl  sp _ _ _) = sp
+  getSpanInfo (RecordDecl sp _ _)   = sp
 
-  setSpanInfo sp (ConstrDecl _ tvar ctx idt ty) = ConstrDecl sp tvar ctx idt ty
-  setSpanInfo sp (ConOpDecl  _ tvar ctx ty1 idt ty2) = ConOpDecl sp tvar ctx ty1 idt ty2
-  setSpanInfo sp (RecordDecl _ tvar ctx idt fd) = RecordDecl sp tvar ctx idt fd
+  setSpanInfo sp (ConstrDecl _ idt ty) = ConstrDecl sp idt ty
+  setSpanInfo sp (ConOpDecl  _ ty1 idt ty2) = ConOpDecl sp ty1 idt ty2
+  setSpanInfo sp (RecordDecl _ idt fd) = RecordDecl sp idt fd
 
-  updateEndPos c@(ConstrDecl _ _ _ _ (t:ts)) =
+  updateEndPos c@(ConstrDecl _ _ (t:ts)) =
     setEndPosition (getSrcSpanEnd (last (t:ts))) c
-  updateEndPos c@(ConstrDecl _ _ _ idt _) =
+  updateEndPos c@(ConstrDecl _ idt _) =
     setEndPosition (incr (getPosition idt) (identLength idt - 1)) c
-  updateEndPos c@(ConOpDecl _ _ _ _ _ ty) =
+  updateEndPos c@(ConOpDecl _ _ _ ty) =
     setEndPosition (getSrcSpanEnd ty) c
-  updateEndPos c@(RecordDecl (SpanInfo _ ss) _ _ _ _) =
+  updateEndPos c@(RecordDecl (SpanInfo _ ss) _ _) =
     setEndPosition (end (last ss)) c
-  updateEndPos c@(RecordDecl _ _ _ _ _) = c
+  updateEndPos c@(RecordDecl _ _ _) = c
 
 instance HasSpanInfo NewConstrDecl where
   getSpanInfo (NewConstrDecl sp _ _)   = sp
